@@ -1,5 +1,5 @@
-
 from PyObjCTools.TestSupport import *
+import objc
 from ScriptingBridge import *
 
 class TestSBApplicationHelper (NSObject):
@@ -10,6 +10,10 @@ class TestSBApplication (TestCase):
     def testMethods(self):
         self.assertResultIsBOOL(SBApplication.isRunning)
 
+    @min_os_level('10.6')
+    def testProtocols(self):
+        objc.protocolNamed('SBApplicationDelegate')
+
 
 if __name__ == "__main__":
     main()
